@@ -1,5 +1,3 @@
-/* -*- c -*- */
-
 function main ()
 {
   System.print ("result1=", add (1, 2, 3), "\n");
@@ -7,3 +5,10 @@ function main ()
 }
 
 main ();
+
+
+/*
+Local variables:
+mode: c
+End:
+*/
