@@ -1,5 +1,3 @@
-/* -*- c -*- */
-
 function main ()
 {
   System.stdout.writeln ("main(): enter");
@@ -41,3 +39,10 @@ function main ()
 }
 
 main ();
+
+
+/*
+Local variables:
+mode: c
+End:
+*/
