@@ -1,4 +1,4 @@
-/*								-*- c -*-
+/*
  * JavaScript Assembler.
  * Copyright (c) 1998 New Generation Software (NGS) Oy
  *
@@ -24,7 +24,7 @@
 
 /*
  * $Source: /usr/local/cvsroot/ngs/js/jsc/asm.js,v $
- * $Id: asm.js,v 1.13 1998/09/10 10:26:05 mtr Exp $
+ * $Id: asm.js,v 1.15 1998/10/26 15:25:21 mtr Exp $
  */
 
 /* Byte-code file definitions. */
@@ -126,6 +126,8 @@ JSC$OP_IFFALSE_B	= 69;
 JSC$OP_IFTRUE_B		= 70;
 JSC$OP_ADD_1_I		= 71;
 JSC$OP_ADD_2_I		= 72;
+JSC$OP_LOAD_GLOBAL_W	= 73;
+JSC$OP_JSR_W		= 74;
 
 /* Internal values. */
 JSC$ASM_SYMBOL		= 1000;
@@ -1262,21 +1264,19 @@ function JSC$ASM_jmp_print (stream)
 
 /* jsr */
 
-function JSC$ASM_jsr (ln, value)
+function JSC$ASM_jsr (ln)
 {
   this.type = JSC$OP_JSR;
   this.linenum = ln;
-  this.value = value;
   this.stack_delta = 1;
-  this.size = 5;
+  this.size = 1;
   this.print = JSC$ASM_jsr_print;
-  this.bytecode = JSC$ASM_bytecode_symbol;
   this.link = JSC$asm_link;
 }
 
 function JSC$ASM_jsr_print (stream)
 {
-  stream.write ("\tjsr\t\t" + this.value + "\n");
+  stream.write ("\tjsr\n");
 }
 
 /* return */
@@ -1575,6 +1575,43 @@ function JSC$ASM_add_2_i_print (stream)
   stream.write ("\tadd_2_i\n");
 }
 
+/* load_global_w */
+
+function JSC$ASM_load_global_w (ln, value)
+{
+  this.type = JSC$OP_LOAD_GLOBAL_W;
+  this.linenum = ln;
+  this.value = value;
+  this.stack_delta = 1;
+  this.size = 5;
+  this.print = JSC$ASM_load_global_w_print;
+  this.bytecode = JSC$ASM_bytecode_symbol;
+  this.link = JSC$asm_link;
+}
+
+function JSC$ASM_load_global_w_print (stream)
+{
+  stream.write ("\tload_global_w\t" + this.value + "\n");
+}
+
+/* jsr_w */
+
+function JSC$ASM_jsr_w (ln, value)
+{
+  this.type = JSC$OP_JSR_W;
+  this.linenum = ln;
+  this.value = value;
+  this.stack_delta = 1;
+  this.size = 5;
+  this.print = JSC$ASM_jsr_w_print;
+  this.bytecode = JSC$ASM_bytecode_symbol;
+  this.link = JSC$asm_link;
+}
+
+function JSC$ASM_jsr_w_print (stream)
+{
+  stream.write ("\tjsr_w\t\t" + this.value + "\n");
+}
 
 /*
  * General helpers.
@@ -2241,3 +2278,10 @@ function JSC$asm_bytecode ()
 	     ? String.pack ("NN", JSC$BC_SECT_DEBUG, debug.length) + debug
 	     : ""));
 }
+
+
+/*
+Local variables:
+mode: c
+End:
+*/
