@@ -1,6 +1,6 @@
-/*								-*- c -*-
+/*
  * Lexer.
- * Copyright (c) 1998 New Generation Software (NGS) Oy
+ * Copyright (c) 1998-1999 New Generation Software (NGS) Oy
  *
  * Author: Markku Rossi <mtr@ngs.fi>
  */
@@ -24,7 +24,7 @@
 
 /*
  * $Source: /usr/local/cvsroot/ngs/js/jsc/lexer.js,v $
- * $Id: lexer.js,v 1.7 1998/09/04 09:44:49 mtr Exp $
+ * $Id: lexer.js,v 1.9 1999/01/11 08:56:30 mtr Exp $
  */
 
 /*
@@ -662,7 +662,7 @@ function JSC$lexer_read_string (stream, name, ender)
 	      ch = JSC$lexer_read_backslash_escape (stream, possible_start_ln,
 						    name);
 	    }
-	  str.append (File.byteToString (ch));
+	  str.append (ch);
 	}
     }
 
@@ -815,3 +815,10 @@ function JSC$lexer_eof_in_constant (possible_start, name)
 
   error (msg);
 }
+
+
+/*
+Local variables:
+mode: c
+End:
+*/
