@@ -1,4 +1,4 @@
-/*								-*- c -*-
+/*
  * Parser.
  * Copyright (c) 1998 New Generation Software (NGS) Oy
  *
@@ -24,7 +24,7 @@
 
 /*
  * $Source: /usr/local/cvsroot/ngs/js/jsc/parser.js,v $
- * $Id: parser.js,v 1.23 1998/10/12 11:47:00 mtr Exp $
+ * $Id: parser.js,v 1.26 1998/10/26 15:25:21 mtr Exp $
  */
 
 /*
@@ -35,6 +35,7 @@ function JSC$parser_reset ()
 {
   JSC$function = null;
   JSC$global_stmts = null;
+  JSC$nested_function_declarations = null;
 }
 
 
@@ -44,6 +45,8 @@ function JSC$parser_parse (stream)
   JSC$filename = stream.name;
   JSC$functions = new Array ();
   JSC$global_stmts = new Array ();
+  JSC$nested_function_declarations = new Array ();
+  JSC$anonymous_function_count = 0;
   JSC$parser_peek_token_valid = false;
   JSC$num_tokens = 0;
   JSC$num_arguments_identifiers = 0;
@@ -182,20 +185,21 @@ function JSC$parser_expr_is_left_hand_side (expr)
 
 function JSC$parser_parse_source_element (stream)
 {
-  var stmt = JSC$parser_parse_stmt (stream);
-  if (typeof stmt != "boolean")
-    {
-      if (stmt.stype == JSC$STMT_VARIABLE)
-	/*
-	 * This is a variable declaration at the global level.  These
-	 * are actually global variables.
-	 */
-	stmt.global_level = true;
+  if (JSC$parser_parse_function_declaration (stream))
+    return true;
 
-      JSC$global_stmts.push (stmt);
-    }
-  else
-    return JSC$parser_parse_function_declaration (stream);
+  var stmt = JSC$parser_parse_stmt (stream);
+  if (!stmt)
+    return false;
+
+  if (stmt.stype == JSC$STMT_VARIABLE)
+    /*
+     * This is a variable declaration at the global level.  These
+     * are actually global variables.
+     */
+    stmt.global_level = true;
+
+  JSC$global_stmts.push (stmt);
 
   return true;
 }
@@ -203,7 +207,7 @@ function JSC$parser_parse_source_element (stream)
 
 function JSC$parser_parse_function_declaration (stream)
 {
-  var id, args, block, ln;
+  var id, args, block;
 
   if (JSC$parser_peek_token (stream) != JSC$tFUNCTION)
     return false;
@@ -216,7 +220,15 @@ function JSC$parser_parse_function_declaration (stream)
     JSC$parser_syntax_error ();
 
   id = JSC$parser_token_value;
-  ln = JSC$parser_token_linenum;
+  var ln = JSC$parser_token_linenum;
+  var id_given = id;
+
+  if (JSC$nested_function_declarations.length > 0)
+    {
+      /* This is a nested function declaration. */
+      id = ".F:" + (JSC$anonymous_function_count++).toString ();
+    }
+  JSC$nested_function_declarations.push (id);
 
   if (JSC$parser_get_token (stream) != #'(')
     JSC$parser_syntax_error ();
@@ -261,9 +273,12 @@ function JSC$parser_parse_function_declaration (stream)
 		     + "instance is deprecated");
     }
 
-  JSC$functions.push (new JSC$function_declaration (ln, lbrace_ln, id, args,
+  JSC$functions.push (new JSC$function_declaration (ln, lbrace_ln, id,
+						    id_given, args,
 						    block, use_arguments));
 
+  JSC$nested_function_declarations.pop ();
+
   return true;
 }
 
@@ -324,6 +339,27 @@ function JSC$parser_parse_stmt (stream)
 
   if (typeof (item = JSC$parser_parse_block (stream)) != "boolean")
     return new JSC$stmt_block (item.linenum, item);
+  else if (JSC$parser_parse_function_declaration (stream))
+    {
+      /* XXX The function declaration as statement might be incomplete. */
+
+      if (JSC$nested_function_declarations.length == 0)
+	/* Function declaration at top-level statements. */
+	return new JSC$stmt_empty (JSC$parser_token_linenum);
+
+      /* Function declaration inside another function. */
+
+      var container_id = JSC$nested_function_declarations.pop ();
+      JSC$nested_function_declarations.push (container_id);
+
+      var f = JSC$functions[JSC$functions.length - 1];
+      var function_id = f.name;
+      var given_id = f.name_given;
+
+      return new JSC$stmt_function_declaration (JSC$parser_token_linenum,
+						container_id, function_id,
+						given_id);
+    }
   else if (typeof (item = JSC$parser_parse_variable_stmt (stream))
 	   != "boolean")
     return item;
@@ -1650,3 +1686,10 @@ function JSC$parser_parse_arguments (stream)
 
   return args;
 }
+
+
+/*
+Local variables:
+mode: c
+End:
+*/
