@@ -1,5 +1,3 @@
-/* -*- c -*- */
-
 function t1 ()
 {
   1
@@ -37,3 +35,10 @@ t3 ()
 
 { 1
     2 } 3
+
+
+/*
+Local variables:
+mode: c
+End:
+*/
