@@ -1,4 +1,4 @@
-/*								-*- c -*-
+/*
  * Process the jswrap input files and generate output.
  * Copyright (c) 1998 New Generation Software (NGS) Oy
  *
@@ -24,7 +24,7 @@
 
 /*
  * $Source: /usr/local/cvsroot/ngs/js/jswrap/process.js,v $
- * $Id: process.js,v 1.8 1998/09/07 12:59:31 mtr Exp $
+ * $Id: process.js,v 1.9 1998/10/27 07:40:40 mtr Exp $
  */
 
 /*
@@ -881,3 +881,10 @@ function trailers ()
   var stream = ofp_h;
   stream.write ("\n#endif /* not " + path_to_ppname (header_file) + " */\n");
 }
+
+
+/*
+Local variables:
+mode: c
+End:
+*/
