@@ -1,6 +1,6 @@
 /*
  * The builtin File object.
- * Copyright (c) 1998 New Generation Software (NGS) Oy
+ * Copyright (c) 1998-1999 New Generation Software (NGS) Oy
  *
  * Author: Markku Rossi <mtr@ngs.fi>
  */
@@ -24,7 +24,7 @@
 
 /*
  * $Source: /usr/local/cvsroot/ngs/js/src/b_file.c,v $
- * $Id: b_file.c,v 1.13 1998/09/29 12:33:35 mtr Exp $
+ * $Id: b_file.c,v 1.14 1999/01/19 13:02:40 mtr Exp $
  */
 
 /*
@@ -124,6 +124,9 @@ struct file_instance_ctx_st
 
   char *path;
   JSIOStream *stream;
+
+  /* Needed for the delete_proc. */
+  JSVirtualMachine *vm;
 };
 
 typedef struct file_instance_ctx_st FileInstanceCtx;
@@ -414,9 +417,12 @@ method (JSVirtualMachine *vm, JSBuiltinInfo *builtin_info,
 	  if (ictx->stream == NULL)
 	    {
 	      /* Do open. */
+	      JS_VM_ALLOCATE_FD (vm, "File.open()");
 	      ictx->stream = js_iostream_file (fopen (ictx->path, buf), readp,
 					       writep, 1);
-	      if (ictx->stream != NULL)
+	      if (ictx->stream == NULL)
+		JS_VM_FREE_FD (vm);
+	      else
 		result_return->u.vboolean = 1;
 	    }
 	}
@@ -428,7 +434,10 @@ method (JSVirtualMachine *vm, JSBuiltinInfo *builtin_info,
 	      int result = 0;
 
 	      if (!ictx->dont_close)
-		result = js_iostream_close (ictx->stream);
+		{
+		  result = js_iostream_close (ictx->stream);
+		  JS_VM_FREE_FD (vm);
+		}
 
 	      ictx->stream = NULL;
 	      result_return->u.vboolean = result >= 0;
@@ -892,6 +901,7 @@ new_proc (JSVirtualMachine *vm, JSBuiltinInfo *builtin_info, JSNode *args,
 
   instance = js_calloc (vm, 1, sizeof (*instance));
   instance->path = js_string_to_c_string (vm, &args[1]);
+  instance->vm = vm;
 
   js_vm_builtin_create (vm, result_return, builtin_info, instance);
 }
@@ -907,7 +917,10 @@ delete_proc (JSBuiltinInfo *builtin_info, void *instance_context)
       if (ictx->stream)
 	{
 	  if (!ictx->dont_close)
-	    js_iostream_close (ictx->stream);
+	    {
+	      js_iostream_close (ictx->stream);
+	      JS_VM_FREE_FD (ictx->vm);
+	    }
 
 	  ictx->stream = NULL;
 	}
@@ -992,6 +1005,7 @@ js_builtin_File_new (JSVirtualMachine *vm, JSNode *result_return,
   ictx->path = js_strdup (vm, path);
   ictx->stream = stream;
   ictx->dont_close = dont_close;
+  ictx->vm = vm;
 
   /* Create the builtin. */
   js_vm_builtin_create (vm, result_return, n->u.vbuiltin->info, ictx);
