@@ -146,65 +146,16 @@ case 18:
 case 19:
   READ_INT32 (j);
 
-  {
-    int found = 0;
+  /* Use the global value only. */
+  JS_COPY (JS_SP0, JS_GLOBAL (j));
+  JS_PUSH ();
 
-    /* Loop over the with chain. */
-    /* WITHCHAIN */
-    if (JS_WITHPTR->u.iptr)
-      {
-	unsigned int *uip = JS_WITHPTR->u.iptr;
-	unsigned int ui = *uip;
-	JSNode *wp = (JSNode *) ((unsigned char *) uip
-				 + sizeof (unsigned int));
-
-	for (i = 0; i < ui; i++)
-	  {
-	    JSNode *w = &wp[i];
-	    int result = JS_PROPERTY_UNKNOWN;
-
-	    if (w->type == JS_BUILTIN)
-	      {
-		JS_SAVE_REGS ();
-		if (w->u.vbuiltin->info->property_proc)
-		  result = (*w->u.vbuiltin->info->property_proc) (
-					vm,
-					w->u.vbuiltin->info,
-					w->u.vbuiltin->instance_context,
-					j, 0, &builtin_result);
-	      }
-	    else if (w->type == JS_OBJECT)
-	      {
-		result = js_vm_object_load_property (vm, w->u.vobject, j,
-						     &builtin_result);
-	      }
-	    else
-	      ERROR ("corrupted with-chain in load_global");
-
-	    if (result == JS_PROPERTY_FOUND)
-	      {
-		JS_COPY (JS_SP0, &builtin_result);
-		JS_PUSH ();
-		found = 1;
-		break;
-	      }
-	  }
-      }
-
-    if (!found)
-      {
-	/* Use the global value. */
-	JS_COPY (JS_SP0, JS_GLOBAL (j));
-	JS_PUSH ();
-
-	if (vm->warn_undef && JS_SP1->type == JS_UNDEFINED)
-	  {
-	    sprintf (buf, "VM: warning: using undefined global `%s'%s",
-		     js_vm_symname (vm, j), JS_HOST_LINE_BREAK);
-	    js_iostream_write (vm->s_stderr, buf, strlen (buf));
-	  }
-      }
-  }
+  if (vm->warn_undef && JS_SP1->type == JS_UNDEFINED)
+    {
+      sprintf (buf, "VM: warning: using undefined global `%s'%s",
+	       js_vm_symname (vm, j), JS_HOST_LINE_BREAK);
+      js_iostream_write (vm->s_stderr, buf, strlen (buf));
+    }
   break;
 
 /* operand store_global (20) */
@@ -1538,101 +1489,39 @@ case 54:
 
 /* operand jsr (55) */
 case 55:
-  /* Read the subroutine symbol index. */
-  READ_INT32 (j);
-
+  /* Call the global method. */
   {
-    int found = 0;
+    JSNode f;
 
-    /* Loop over the with-chain. */
-    /* WITHCHAIN */
-    if (JS_WITHPTR->u.iptr)
+    /* Fetch the function to our local variable. */
+    JS_COPY (&f, JS_SP1);
+    function = &f;
+
+    /* Reset the `this' to null. */
+    JS_SP1->type = JS_NULL;
+
+    if (function->type == JS_BUILTIN
+	&& function->u.vbuiltin->info->global_method_proc)
       {
-	unsigned int *uip = JS_WITHPTR->u.iptr;
-	unsigned int ui = *uip;
-	JSNode *wp = (JSNode *) ((unsigned char *) uip
-				 + sizeof (unsigned int));
-
-	for (i = 0; i < ui; i++)
-	  {
-	    JSNode *w = &wp[i];
-	    int result = JS_PROPERTY_UNKNOWN;
-
-	    if (w->type == JS_BUILTIN)
-	      {
-		JS_SAVE_REGS ();
-		if (w->u.vbuiltin->info->method_proc)
-		  result = (*w->u.vbuiltin->info->method_proc) (
-					vm,
-					w->u.vbuiltin->info,
-					w->u.vbuiltin->instance_context, j,
-					&builtin_result, JS_SP2);
-		JS_MAYBE_GC ();
-
-		if (result == JS_PROPERTY_FOUND)
-		  {
-		    JS_COPY (JS_SP0, &builtin_result);
-		    JS_PUSH ();
-		  }
-	      }
-	    else if (w->type == JS_OBJECT)
-	      {
-		JSNode method;
-
-		js_vm_object_load_property (vm, w->u.vobject, j, &method);
-		if (method.type == JS_FUNC)
-		  {
-		    result = JS_PROPERTY_FOUND;
-
-		    /* Hopefully for the last time: do a subroutine call. */
-
-		    /* First: replace the null `this' with `w'. */
-		    JS_COPY (JS_SP1, w);
-
-		    /* Then, do the normal subroutine call. */
-		    JS_SUBROUTINE_CALL (method.u.vfunction->implementation);
-		  }
-	      }
-	    else
-	      ERROR ("corrupted with-chain in jsr");
-
-	    if (result == JS_PROPERTY_FOUND)
-	      {
-		found = 1;
-		break;
-	      }
-	  }
-      }
-
-    if (!found)
-      {
-	/* Call the global method. */
-	function = JS_GLOBAL (j);
-
-	if (function->type == JS_BUILTIN
-	    && function->u.vbuiltin->info->global_method_proc)
-	  {
-	    JS_SAVE_REGS ();
-	    (*function->u.vbuiltin->info->global_method_proc) (
+	JS_SAVE_REGS ();
+	(*function->u.vbuiltin->info->global_method_proc) (
 				vm,
 				function->u.vbuiltin->info,
 				function->u.vbuiltin->instance_context,
 				&builtin_result,
 				JS_SP2);
 
-	    JS_COPY (JS_SP0, &builtin_result);
-	    JS_PUSH ();
-	  }
-	else if (function->type == JS_FUNC)
-	  {
-	    JS_SUBROUTINE_CALL (function->u.vfunction->implementation);
-	  }
-	else
-	  {
-	    sprintf (buf, "symbol `%s' is undefined as function",
-		     js_vm_symname (vm, j));
-	    ERROR (buf);
-	  }
+	JS_COPY (JS_SP0, &builtin_result);
+	JS_PUSH ();
+      }
+    else if (function->type == JS_FUNC)
+      {
+	JS_SUBROUTINE_CALL (function->u.vfunction->implementation);
+      }
+    else
+      {
+	sprintf (buf, "illegal function object in jsr");
+	ERROR (buf);
       }
   }
   break;
@@ -1936,14 +1825,16 @@ case 64:
   if (JS_SP1->type != JS_OBJECT && JS_SP1->type != JS_BUILTIN)
     ERROR ("illegal object for with_push");
 
+  /* WITHCHAIN */
+
   if (JS_WITHPTR->u.iptr == NULL)
     {
       JSNode *np;
-      unsigned int *ip = js_vm_alloc (vm,
-				      sizeof (unsigned int)
-				      + sizeof (JSNode));
+      JSUIntAlign *ip = js_vm_alloc (vm,
+				     sizeof (JSUIntAlign)
+				     + sizeof (JSNode));
       *ip = 1;
-      np = (JSNode *) ((unsigned char *) ip + sizeof (unsigned int));
+      np = (JSNode *) ((unsigned char *) ip + sizeof (JSUIntAlign));
 
       JS_COPY (np, JS_SP1);
       JS_WITHPTR->u.iptr = ip;
@@ -1951,14 +1842,14 @@ case 64:
   else
     {
       JSNode *np;
-      unsigned int *ip = JS_WITHPTR->u.iptr;
-      unsigned int ui = *ip;
+      JSUIntAlign *ip = JS_WITHPTR->u.iptr;
+      JSUIntAlign ui = *ip;
 
       ip = js_vm_realloc (vm, ip,
-			  sizeof (unsigned int)
+			  sizeof (JSUIntAlign)
 			  + ((ui + 1) * sizeof (JSNode)));
       (*ip)++;
-      np = (JSNode *) ((unsigned char *) ip + sizeof (unsigned int));
+      np = (JSNode *) ((unsigned char *) ip + sizeof (JSUIntAlign));
 
       JS_COPY (&np[ui], JS_SP1);
       JS_WITHPTR->u.iptr = ip;
@@ -1971,8 +1862,10 @@ case 64:
 case 65:
   READ_INT8 (i);
 
+  /* WITHCHAIN */
+
   {
-    unsigned int *ip = JS_WITHPTR->u.iptr;
+    JSUIntAlign *ip = JS_WITHPTR->u.iptr;
 
     if (ip == NULL || *ip < i)
       ERROR ("with stack underflow in with_pop");
@@ -2098,3 +1991,174 @@ case 72:
   JS_SP1->u.vinteger += 2;
   break;
 
+/* operand load_global_w (73) */
+case 73:
+  READ_INT32 (j);
+  {
+    int found = 0;
+
+    /* Loop over the with chain. */
+    /* WITHCHAIN */
+    if (JS_WITHPTR->u.iptr)
+      {
+	JSUIntAlign *uip = JS_WITHPTR->u.iptr;
+	JSUIntAlign ui = *uip;
+	JSNode *wp = (JSNode *) ((unsigned char *) uip
+				 + sizeof (JSUIntAlign));
+
+	for (i = 0; i < ui; i++)
+	  {
+	    JSNode *w = &wp[i];
+	    int result = JS_PROPERTY_UNKNOWN;
+
+	    if (w->type == JS_BUILTIN)
+	      {
+		JS_SAVE_REGS ();
+		if (w->u.vbuiltin->info->property_proc)
+		  result = (*w->u.vbuiltin->info->property_proc) (
+					vm,
+					w->u.vbuiltin->info,
+					w->u.vbuiltin->instance_context,
+					j, 0, &builtin_result);
+	      }
+	    else if (w->type == JS_OBJECT)
+	      {
+		result = js_vm_object_load_property (vm, w->u.vobject, j,
+						     &builtin_result);
+	      }
+	    else
+	      ERROR ("corrupted with-chain in load_global");
+
+	    if (result == JS_PROPERTY_FOUND)
+	      {
+		JS_COPY (JS_SP0, &builtin_result);
+		JS_PUSH ();
+		found = 1;
+		break;
+	      }
+	  }
+      }
+
+    if (!found)
+      {
+	/* Use the global value. */
+	JS_COPY (JS_SP0, JS_GLOBAL (j));
+	JS_PUSH ();
+
+	if (vm->warn_undef && JS_SP1->type == JS_UNDEFINED)
+	  {
+	    sprintf (buf, "VM: warning: using undefined global `%s'%s",
+		     js_vm_symname (vm, j), JS_HOST_LINE_BREAK);
+	    js_iostream_write (vm->s_stderr, buf, strlen (buf));
+	  }
+      }
+  }
+  break;
+
+/* operand jsr_w (74) */
+case 74:
+  /* Read the subroutine symbol index. */
+  READ_INT32 (j);
+
+  {
+    int found = 0;
+
+    /* Loop over the with-chain. */
+    /* WITHCHAIN */
+    if (JS_WITHPTR->u.iptr)
+      {
+	JSUIntAlign *uip = JS_WITHPTR->u.iptr;
+	JSUIntAlign ui = *uip;
+	JSNode *wp = (JSNode *) ((unsigned char *) uip
+				 + sizeof (JSUIntAlign));
+
+	for (i = 0; i < ui; i++)
+	  {
+	    JSNode *w = &wp[i];
+	    int result = JS_PROPERTY_UNKNOWN;
+
+	    if (w->type == JS_BUILTIN)
+	      {
+		JS_SAVE_REGS ();
+		if (w->u.vbuiltin->info->method_proc)
+		  result = (*w->u.vbuiltin->info->method_proc) (
+					vm,
+					w->u.vbuiltin->info,
+					w->u.vbuiltin->instance_context, j,
+					&builtin_result, JS_SP2);
+		JS_MAYBE_GC ();
+
+		if (result == JS_PROPERTY_FOUND)
+		  {
+		    JS_COPY (JS_SP0, &builtin_result);
+		    JS_PUSH ();
+		  }
+	      }
+	    else if (w->type == JS_OBJECT)
+	      {
+		JSNode method;
+
+		js_vm_object_load_property (vm, w->u.vobject, j, &method);
+		if (method.type == JS_FUNC)
+		  {
+		    result = JS_PROPERTY_FOUND;
+
+		    /* The object defines the method.  Do a subroutine call. */
+
+		    /* First: replace the null `this' with `w'. */
+		    JS_COPY (JS_SP1, w);
+
+		    /* Then, do the normal subroutine call. */
+		    JS_SUBROUTINE_CALL (method.u.vfunction->implementation);
+		  }
+	      }
+	    else
+	      ERROR ("corrupted with-chain in jsr_w");
+
+	    if (result == JS_PROPERTY_FOUND)
+	      {
+		found = 1;
+		break;
+	      }
+	  }
+      }
+
+    if (!found)
+      {
+	JSNode f;
+
+	/* Call the global method. */
+	JS_COPY (&f, JS_SP1);
+	function = &f;
+
+	/* Reset the `this' to null. */
+	JS_SP1->type = JS_NULL;
+
+	if (function->type == JS_BUILTIN
+	    && function->u.vbuiltin->info->global_method_proc)
+	  {
+	    JS_SAVE_REGS ();
+	    (*function->u.vbuiltin->info->global_method_proc) (
+				vm,
+				function->u.vbuiltin->info,
+				function->u.vbuiltin->instance_context,
+				&builtin_result,
+				JS_SP2);
+
+	    JS_COPY (JS_SP0, &builtin_result);
+	    JS_PUSH ();
+	  }
+	else if (function->type == JS_FUNC)
+	  {
+	    JS_SUBROUTINE_CALL (function->u.vfunction->implementation);
+	  }
+	else
+	  {
+	    sprintf (buf, "symbol `%s' is undefined as function",
+		     js_vm_symname (vm, j));
+	    ERROR (buf);
+	  }
+      }
+  }
+  break;
+
