@@ -1,6 +1,6 @@
 /*
  * JavaScript interpreter main glue.
- * Copyright (c) 1998 New Generation Software (NGS) Oy
+ * Copyright (c) 1998-1999 New Generation Software (NGS) Oy
  *
  * Author: Markku Rossi <mtr@ngs.fi>
  */
@@ -24,7 +24,7 @@
 
 /*
  * $Source: /usr/local/cvsroot/ngs/js/src/js.c,v $
- * $Id: js.c,v 1.29 1998/10/20 08:44:32 mtr Exp $
+ * $Id: js.c,v 1.33 1999/01/19 13:02:40 mtr Exp $
  */
 
 #include "js.h"
@@ -177,6 +177,8 @@ js_init_default_options (JSInterpOptions *options)
 
   options->optimize_peephole = 1;
   options->optimize_jumps_to_jumps = 1;
+
+  options->fd_count = (unsigned long) -1;
 }
 
 
@@ -190,6 +192,12 @@ js_create_interp (JSInterpOptions *options)
   JSIOStream *s_stdout = NULL;
   JSIOStream *s_stderr = NULL;
 
+  /*
+   * Sanity check to assure that the js.h and jsint.h APIs share a
+   * same view to the world.
+   */
+  assert (sizeof (JSNode) == sizeof (JSType));
+
   interp = js_calloc (NULL, 1, sizeof (*interp));
   if (interp == NULL)
     return NULL;
@@ -239,6 +247,9 @@ js_create_interp (JSInterpOptions *options)
   if (interp->vm == NULL)
     goto error_out;
 
+  /* Set some options. */
+  interp->vm->warn_undef = options->warn_undef;
+
   /* Set the security options. */
 
   if (options->secure_builtin_file)
@@ -251,6 +262,9 @@ js_create_interp (JSInterpOptions *options)
   interp->vm->hook_context		 = options->hook_context;
   interp->vm->hook_operand_count_trigger = options->hook_operand_count_trigger;
 
+  /* The file descriptor limit. */
+  interp->vm->fd_count = options->fd_count;
+
   if (!options->no_compiler)
     {
       int result;
@@ -1630,6 +1644,7 @@ iofunc_get_length (void *context)
 static void
 iofunc_close (void *context)
 {
+  js_free (context);
 }
 
 
@@ -1645,7 +1660,7 @@ iostream_iofunc (JSIOFunc func, void *context, int readp, int writep)
   ctx = js_malloc (NULL, sizeof (*ctx));
   if (ctx == NULL)
     {
-      js_free (stream);
+      (void) js_iostream_close (stream);
       return NULL;
     }
 
