@@ -24,7 +24,7 @@
 
 /*
  * $Source: /usr/local/cvsroot/ngs/js/src/vm.c,v $
- * $Id: vm.c,v 1.16 1998/10/07 12:27:50 mtr Exp $
+ * $Id: vm.c,v 1.17 1998/10/26 14:02:42 mtr Exp $
  */
 
 #include "jsint.h"
@@ -301,6 +301,7 @@ js_vm_execute (JSVirtualMachine *vm, JSByteCode *bc)
   int result = 1;
   unsigned char *debug_info;
   unsigned int debug_info_len;
+  unsigned int anonymous_function_offset;
 
   /* We need a toplevel over the whole function. */
 
@@ -327,6 +328,8 @@ js_vm_execute (JSVirtualMachine *vm, JSByteCode *bc)
 
       /* Process constants. */
       consts_offset = vm->num_consts;
+      anonymous_function_offset = vm->anonymous_function_next_id;
+
       for (sect = 0; sect < bc->num_sects; sect++)
 	if (bc->sects[sect].type == JS_BCST_CONSTANTS)
 	  {
@@ -387,9 +390,13 @@ js_vm_execute (JSVirtualMachine *vm, JSByteCode *bc)
 		      buf[i] = cp[ui];
 		    buf[i] = '\0';
 
-		    /* Eath the trailing '\0' from the data. */
+		    /* Eat the trailing '\0' from the data. */
 		    ui++;
 
+		    if (buf[0] == '.' && buf[1] == 'F' && buf[2] == ':')
+		      sprintf (buf + 3, "%u",
+			       vm->anonymous_function_next_id++);
+
 		    /* Intern symbol. */
 		    c->u.vsymbol = js_vm_intern (vm, buf);
 		    break;
@@ -495,6 +502,7 @@ js_vm_execute (JSVirtualMachine *vm, JSByteCode *bc)
       /* Execute. */
       result = (*vm->dispatch_execute) (vm, bc, symtab, num_symtab_entries,
 					consts_offset,
+					anonymous_function_offset,
 					debug_info, debug_info_len,
 					NULL, NULL, 0, NULL);
     }
@@ -565,7 +573,7 @@ js_vm_apply (JSVirtualMachine *vm, char *func_name, JSNode *func,
 	  PROFILING_ON ();
 
 	  /* Call function. */
-	  result = (*vm->dispatch_execute) (vm, NULL, NULL, 0, 0,
+	  result = (*vm->dispatch_execute) (vm, NULL, NULL, 0, 0, 0,
 					    NULL, 0,
 					    NULL, func, argc, argv);
 	}
@@ -686,8 +694,9 @@ js_vm_call_method (JSVirtualMachine *vm, JSNode *object,
 	      else
 		{
 		  PROFILING_ON ();
-		  result = (*vm->dispatch_execute) (vm, NULL, NULL, 0, 0, NULL,
-						    0, object, &method, argc,
+		  result = (*vm->dispatch_execute) (vm, NULL, NULL, 0, 0, 0,
+						    NULL, 0,
+						    object, &method, argc,
 						    argv);
 		}
 	    }
